"""Coding agents for KISS framework."""

import kiss.agents.coding_agents.config  # type: ignore # noqa: F401
from kiss.core.base import CODING_INSTRUCTIONS, Base

__all__ = [
    "Base",
    "CODING_INSTRUCTIONS",
]
